@@ -1,5 +1,5 @@
-#ifndef __MOBIUS_PYTHON_IO_FILE_H__
-#define __MOBIUS_PYTHON_IO_FILE_H__
+#ifndef MOBIUS_PYTHON_IO_FILE_H
+#define MOBIUS_PYTHON_IO_FILE_H
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
@@ -32,7 +32,9 @@ typedef struct
 
 extern PyTypeObject io_file_t;
 
-// helper functions
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+// Helper functions
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyObject *PyMobius_IO_File_from_cpp (mobius::io::file);
 
 #endif
